from enum import Enum


class Formats(Enum):
    PDF = "pdf"
    TXT = "txt"
    DOCX = "docx"
    HTML = "html"
    RICH_TEXT = "rtf"
    OPEN_DOCUMENT_TEXT = "odt"
    EPUB = "epub"
    ZIP = "zip"
