from gdoc_dumper import Formats

print(Formats.TXT.value)
print(Formats.PDF.value)
print(Formats.DOCX.value)
print(Formats.EPUB.value)
print(Formats.HTML.value)
print(Formats.OPEN_DOCUMENT_TEXT.value)
print(Formats.RICH_TEXT.value)
print(Formats.ZIP.value)
